#
# spec file for package python-crochet
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        Use Twisted from threaded applications
License:        MIT
Group:          Development/Languages/Python
Name:           python-crochet
Version:        1.5.0
Release:        1.150
Source0:        crochet-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-Sphinx
BuildRequires:  python-Twisted
BuildRequires:  python-devel
Requires:       python-Twisted
BuildArch:      noarch
Url:            https://github.com/itamarst/crochet

%description
Crochet is an MIT-licensed library that makes it easier for blocking or
threaded applications like Flask or Django to use the Twisted networking
framework. Crochet provides the following features:

* Runs Twisted's reactor in a thread it manages.
* The reactor shuts down automatically when the process' main thread finishes.
* Hooks up Twisted's log system to the Python standard library ``logging``
  framework. Unlike Twisted's built-in ``logging`` bridge, this includes
  support for blocking `Handler` instances.
* A blocking API to eventual results (i.e. ``Deferred`` instances). This last
  feature can be used separately, so Crochet is also useful for normal Twisted
  applications that use threads.

Documentation can be found on `Read The Docs`_.

Bugs and feature requests should be filed at the project `Github page`_.

.. _Read the Docs: https://crochet.readthedocs.org/
.. _Github page: https://github.com/itamarst/crochet/

%package doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Python
Recommends:     %{name}

%description doc
Documentation and help files for %{name}

%prep
%setup -q -n crochet-%{version}

%build
python setup.py build

%install
python setup.py install -O1 --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}%{python_sitelib}

cd docs
make html
rm _build/html/.buildinfo

%files
%defattr(-,root,root)
%doc LICENSE README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc docs/_build/html docs/_build/doctrees examples/

%changelog
* Thu Apr 14 2016 termim@gmail.com
- Update to 1.5.0
  * New features:
  - Added support for Python 3.5.
  * Removed features:
  - Python 2.6, Python 3.3, and versions of Twisted < 15.0 are no longer
    supported.
- Update to 1.4.0
  * New features:
  - Added support for Python 3.4.
  * Documentation:
  - Added a section on known issues and workarounds.
  * Bug fixes:
  - Main thread detection (used to determine when Crochet should
    shutdown) is now less fragile. This means Crochet now supports more
    environments, e.g. uWSGI. Thanks to Ben Picolo for the patch.
* Sun Jun  1 2014 termim@gmail.com
- Update to 1.3.0
  * Bug fixes:
  - It is now possible to call ``EventualResult.wait()`` (or functions
    wrapped in ``wait_for``) at import time if another thread holds the
    import lock. Thanks to Ken Struys for the patch.
- Update to 1.2.0
  * New features:
  - ``crochet.wait_for`` implements the timeout/cancellation pattern documented
    in previous versions of Crochet. ``crochet.wait_for_reactor`` and
    ``EventualResult.wait(timeout=None)`` are now deprecated, since lacking
    timeouts they could potentially block forever.
  - Functions wrapped with ``wait_for`` and ``run_in_reactor`` can now be accessed
    via the ``wrapped_function`` attribute, to ease unit testing of the underlying
    Twisted code.
  * API changes:
  - It is no longer possible to call ``EventualResult.wait()`` (or functions
    wrapped with ``wait_for``) at import time, since this can lead to deadlocks
    or prevent other threads from importing. Thanks to Tom Prince for the bug
    report.
  * Bug fixes:
  - ``warnings`` are no longer erroneously turned into Twisted log messages.
  - The reactor is now only imported when ``crochet.setup()`` or
    ``crochet.no_setup()`` are called, allowing daemonization if only ``crochet``
    is imported (http://tm.tl/7105). Thanks to Daniel Nephin for the bug report.
* Sat Mar 15 2014 termim@gmail.com
- Update to 1.1.0
  * Bug fixes:
  - EventualResult.wait() can now be used safely from multiple threads,
    thanks to Gavin Panella for reporting the bug.
  - Fixed reentrancy deadlock in the logging code caused by
    http://bugs.python.org/issue14976, thanks to Rod Morehead for
    reporting the bug.
  - Crochet now installs on Python 3.3 again, thanks to Ben Cordero.
  - Crochet should now work on Windows, thanks to Konstantinos
    Koukopoulos.
  - Crochet tests can now run without adding its absolute path to
    PYTHONPATH or installing it first.
  * Documentation:
  - EventualResult.original_failure is now documented.
* Tue Feb 25 2014 termim@gmail.com
- v.1.0.0 - Initial rpm release
